aboutsummaryrefslogtreecommitdiff
path: root/src/wallet/wallet.cpp
diff options
context:
space:
mode:
authorAndrew Chow <achow101-github@achow101.com>2021-05-06 14:12:13 -0400
committerAndrew Chow <achow101-github@achow101.com>2021-05-13 16:40:56 -0400
commit1bf4a62cb61bd4b91d9cd4e379fea2b914786342 (patch)
tree3bdc8fa6615092678bf756dfcb33a3ee2eed7a78 /src/wallet/wallet.cpp
parentb34bf2b42caaee7c8714c1229e877128916d914a (diff)
downloadbitcoin-1bf4a62cb61bd4b91d9cd4e379fea2b914786342.tar.xz
scripted-diff: rename some variables
actual_target -> selection_target nChange -> change_and_fee -BEGIN VERIFY SCRIPT- sed -i -e 's/actual_target/selection_target/g' src/wallet/coinselection.cpp sed -i -e '2801,3691s/nChange /change_and_fee /g' src/wallet/wallet.cpp sed -i -e '2801,3691s/nChange,/change_and_fee,/g' src/wallet/wallet.cpp sed -i -e '2801,3691s/nChange;/change_and_fee;/g' src/wallet/wallet.cpp -END VERIFY SCRIPT-
Diffstat (limited to 'src/wallet/wallet.cpp')
-rw-r--r--src/wallet/wallet.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/wallet/wallet.cpp b/src/wallet/wallet.cpp
index 456c26ea31..35805bc4c9 100644
--- a/src/wallet/wallet.cpp
+++ b/src/wallet/wallet.cpp
@@ -2990,19 +2990,19 @@ bool CWallet::CreateTransactionInternal(
bnb_used = false;
}
- const CAmount nChange = nValueIn - nValueToSelect;
- if (nChange > 0)
+ const CAmount change_and_fee = nValueIn - nValueToSelect;
+ if (change_and_fee > 0)
{
// Fill a vout to ourself
- CTxOut newTxOut(nChange, scriptChange);
+ CTxOut newTxOut(change_and_fee, scriptChange);
// Never create dust outputs; if we would, just
// add the dust to the fee.
// The nChange when BnB is used is always going to go to fees.
if (IsDust(newTxOut, coin_selection_params.m_discard_feerate) || bnb_used)
{
nChangePosInOut = -1;
- nFeeRet += nChange;
+ nFeeRet += change_and_fee;
}
else
{
@@ -2990,19 +2990,19 @@ bool CWallet::CreateTransactionInternal(
// Never create dust outputs; if we would, just
// add the dust to the fee.
- // The nChange when BnB is used is always going to go to fees.
+ // The change_and_fee when BnB is used is always going to go to fees.
if (IsDust(newTxOut, coin_selection_params.m_discard_feerate) || bnb_used)
{